@@ -30,7 +30,7 @@ from cryptography.hazmat.primitives.asymmetric.utils import (
 
 from paramiko.common import four_byte
 from paramiko.message import Message
-from paramiko.pkey import PKey
+from paramiko.pkey import PKey, register_pkey_type
 from paramiko.ssh_exception import SSHException
 from paramiko.util import deflate_long
 
@@ -89,12 +89,16 @@ class _ECDSACurveSet(object):
                 return curve
 
 
+@register_pkey_type
 class ECDSAKey(PKey):
     """
     Representation of an ECDSA key which can be used to sign and verify SSH2
     data.
     """
 
+    LEGACY_TYPE = "EC"
+    OPENSSH_TYPE_PREFIX = "ecdsa-sha2-"
+
     _ECDSA_CURVES = _ECDSACurveSet([
         _ECDSACurve(ec.SECP256R1, 'nistp256'),
         _ECDSACurve(ec.SECP384R1, 'nistp384'),
@@ -102,16 +106,18 @@ class ECDSAKey(PKey):
     ])
 
     def __init__(self, msg=None, data=None, filename=None, password=None,
-                 vals=None, file_obj=None, validate_point=True):
+                 vals=None, file_obj=None, validate_point=True, _raw=None):
         self.verifying_key = None
         self.signing_key = None
         self.public_blob = None
         if file_obj is not None:
-            self._from_private_key(file_obj, password)
-            return
+            _raw = self._from_private_key(file_obj, password)
         if filename is not None:
-            self._from_private_key_file(filename, password)
+            _raw = self._from_private_key_file(filename, password)
+        if _raw is not None:
+            self._decode_key(_raw)
             return
+
         if (msg is None) and (data is not None):
             msg = Message(data)
         if vals is not None:
@@ -187,6 +193,9 @@ class ECDSAKey(PKey):
         m.add_string(point_str)
         return m.asbytes()
 
+    def __str__(self):
+        return self.asbytes()
+
     def __hash__(self):
         return hash((self.get_name(), self.verifying_key.public_numbers().x,
                      self.verifying_key.public_numbers().y))
@@ -261,15 +270,6 @@ class ECDSAKey(PKey):
         return ECDSAKey(vals=(private_key, private_key.public_key()))
 
     # ...internals...
-
-    def _from_private_key_file(self, filename, password):
-        data = self._read_private_key_file('EC', "ecdsa-sha2-", filename, password)
-        self._decode_key(data)
-
-    def _from_private_key(self, file_obj, password):
-        data = self._read_private_key('EC', "ecdsa-sha2-", file_obj, password)
-        self._decode_key(data)
-
     def _decode_key(self, data):
         pkformat, data = data
         if pkformat == self.FORMAT_ORIGINAL:
